@@ -6,7 +6,7 @@ use Moose;
 
 use version;
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = version->new("2.03");
+our $VERSION = version->new("2.04");
 
 use Mail::Builder::Role::TypeConstraints;
 
@@ -508,15 +508,19 @@ and inline images
   use Mail::Builder;
   
   my $mail = Mail::Builder->new({
-      subject   => 'Party at Sam\'s place'
+      subject   => 'Party at Sam\'s place',
+      from      => 'mightypirate@meele-island.mq',
+      htmltext  => '<h1>Party invitation</h1> ... ',
+      attachment=> '/path/to/direction_samandmax.pdf',
   });
   
-  $mail->from('mightypirate@meele-island.mq','Guybrush Threepwood');
-  $mail->to->add('manuel.calavera@dod.mx','Manuel Calavera');
-  $mail->cc->add('glotis@dod.mx');
-  $mail->htmltext('<h1>Party invitation</h1> ... ');
-  $mail->attachment->add('direction_samandmax.pdf');
-
+  # Alter from name
+  $mail->from->name('Guybrush Threepwood');
+  # Set recipent
+  $mail->to('manuel.calavera@dod.mx','Manuel Calavera');
+  # Add one more recipient
+  $mail->to->add('glotis@dod.mx');
+  
   # Send it with your favourite module (e.g. Email::Send)
   my $mailer = Email::Send->new({mailer => 'Sendmail'})->send($mail->stringify);
   
@@ -560,8 +564,8 @@ html e-mail body. (E<lt>img src="cid:imageid" /E<gt>)
 
 =item * L<Mail::Builder::List>
 
-Helper class for handling list of varoius items (recipient lists, attachment
-lists, image lists)
+Helper class for handling list of varoius items (i.e. recipient lists, 
+attachment lists and image lists)
 
 =back
 
@@ -571,7 +575,8 @@ lists, image lists)
 
 =head3 new
 
-This is a simple constructor. It accepts all defined acccessors as a HashRef.
+This is a simple constructor. It accepts all defined acccessors as a Hash orr 
+HashRef.
 
 =head2 Public methods 
 
@@ -601,7 +606,7 @@ order to increase the processing speed L<Mail::Builder::Attachment> and
 L<Mail::Builder::Image> entities will be cached and only rebuilt if something
 has changed.
 
-Each call to this method also chages the L<messageid>.
+Each call to this method also changes the C<messageid>.
 
 =head3 purge_cache
 
@@ -627,7 +632,7 @@ returnpath for bounced messages.
      [comment   => COMMENT,]
  });
  
-This accessor always returns a Mail::Builder::Address object. 
+This accessor always returns a Mail::Builder::Address object.
 
 To change the attribute value you can either supply
 
@@ -683,7 +688,7 @@ To alter the values you can either
 list and add the object to the list.
 
 =item * Supply a L<Mail::Builder::List> object. The list object replaces the 
-old one if the list types match
+old one if the list types matches.
 
 =item * Scalar and HashRef values will be passed to 
 C<Mail::Builder::Address-E<gt>new>. The returned object will be added to the 
@@ -712,7 +717,7 @@ methods can be used to check respectively clear the value.
 
 Message ID of the e-mail as a  L<Email::MessageID> object. Read only and 
 available only after the C<build_message> or C<stingify> methods have been 
-called. Each call to C<build_message> or C<stingify> changes the message id.
+called. Each call to C<build_message> or C<stingify> changes the message ID.
 
 =head3 organization
  
@@ -748,8 +753,8 @@ and the C<autotext> option is not turned off. Simple formating (e.g. <strong>,
 <em>) will be converted to pseudo formating.
 
 If you want to disable the autogeneration of plaintext parts set the 
-L<autotext> accessor to a false value. However be aware that most spam 
-enginges mark html e-mail messages without a plaintext part as spam.
+L<autotext> accessor to a false value. However be aware that most anti-spam 
+enginges tag html e-mail messages without a plaintext part as spam.
 
 The following html tags will be transformed to simple markup:
 
@@ -800,7 +805,9 @@ Tables are converted into text using L<Text::Table>.
 
 =head3 autotext
 
-Enables the autogeneration of plaintext parts from HTML. Default TRUE.
+Enables the autogeneration of plaintext parts from HTML. 
+
+Default TRUE.
 
 =head3 attachment
 
@@ -851,13 +858,13 @@ If you want to append an additional attachment to the list use
  OR
  $obj->image(PATH | Path::Class::File | FH | IO::File | ScalarRef)
  OR
- $obj->attachment({
+ $obj->image({
      file       => PATH | Path::Class::File | FH | IO::File | ScalarRef,
      [id        => ID,]
      [mimetype  => MIME,]
  })
  OR
- $obj->attachment([
+ $obj->image([
     HashRef | Mail::Builder::Image | PATH | Path::Class::File | FH | IO::File | ScalarRef
  ]);
  
@@ -899,8 +906,10 @@ attention, or else you might end up with growing recipients lists.
      # Alternatively you could use $mb->to($recipient); which has the
      # same effect as the two previous commands. Same applies to 'cc' and 'bcc'
      
+     # Autogenerated Plaintext will be reset
      $mb->htmltext(qq[<h1>Hello $recipient!</h1> Text, yadda yadda! ]);
      
+     # Plaintext is autogenerated
      my $mail = $mb->stringify();
      
      # Send $mail ... 
@@ -942,13 +951,6 @@ your report as I make changes.
     maros [at] k-1.com
     http://www.k-1.com
 
-=head1 ACKNOWLEDGEMENTS 
-
-This module was written for my old employer the Centre for Social Innovation
-L<http://www.zsi.at> and is currently advanced by Revdev 
-L<http://www.revdev.at>, a nice litte software company I run with Koki and 
-Domm (L<http://search.cpan.org/~domm/>).
-
 =head1 COPYRIGHT
 
 Mail::Builder is Copyright (c) 2007-2010 Maroš Kollár.
@@ -966,6 +968,9 @@ LICENSE file included with this module.
 
 The L<Mime::Entity> module in the L<Mime::Tools> distribution.
 
+L<Mail::Builder::Simple> provides a wrapper around this module and itegrates
+it with L<Email::Sender::Simple>
+
 Furthermore these modules are being used for various tasks:
 
 =over 
